@@ -2,7 +2,8 @@
 # StanHeaders - Used to prevent issues with Prophet dynload error
 
 #' @import StanHeaders
-
+#' @import tidymodels
+NULL
 
 # ON LOAD ----
 
