@@ -21,26 +21,25 @@ test_that("Chunked Recursive Tests - Uneven ", {
     # recursive 1 - single / recipe / parsnip ----
 
     # Lag Recipe
-    recipe_lag <- recipe(value ~ date, m750_extended) %>%
-        step_lag(value, lag = c(3,6,9,12))
+    recipe_lag <- recipes::recipe(value ~ date, m750_extended) %>%
+        recipes::step_lag(value, lag = c(3,6,9,12))
 
     # Data Transformation
-    m750_lagged <- recipe_lag %>% prep() %>% juice()
+    m750_lagged <- recipe_lag %>% recipes::prep() %>% recipes::juice()
 
-    train_data <- m750_lagged %>%
-        drop_na()
+    train_data <- tidyr::drop_na(m750_lagged)
 
     future_data <- m750_lagged %>%
-        filter(is.na(value))
+        dplyr::filter(is.na(value))
 
 
     # * Recursive Modeling ----
     model_fit_lm <- linear_reg() %>%
-        set_engine("lm") %>%
+        parsnip::set_engine("lm") %>%
         fit(value ~ date, data = train_data)
 
     model_fit_lm_recursive <- linear_reg() %>%
-        set_engine("lm") %>%
+        parsnip::set_engine("lm") %>%
         fit(value ~ ., data = train_data) %>%
         recursive(
             transform  = recipe_lag,
@@ -61,7 +60,7 @@ test_that("Chunked Recursive Tests - Uneven ", {
             keep_data   = TRUE
         )
 
-    preds <- forecast_tbl %>% filter(.model_id == 2) %>% pull(.value)
+    preds <- forecast_tbl %>% dplyr::filter(.model_id == 2) %>% dplyr::pull(.value)
     expect_equal(
         length(future_data$value),
         length(preds)
@@ -88,7 +87,7 @@ test_that("Chunked Recursive Tests - Uneven ", {
             actual_data = retrain_tbl
         )
 
-    preds <- forecast_refit_tbl %>% filter(.model_id == 1) %>% pull(.value)
+    preds <- forecast_refit_tbl %>% dplyr::filter(.model_id == 1) %>% dplyr::pull(.value)
     expect_equal(
         length(future_tbl$value),
         length(preds)
@@ -114,23 +113,22 @@ test_that("Chunked Recursive Tests - Uneven ", {
     # Data Preparation
     m750_lagged <- m750_extended %>%
         lag_transformer() %>%
-        select(-id)
+        dplyr::select(-id)
 
-    train_data <- m750_lagged %>%
-        drop_na()
+    train_data <- drop_na(m750_lagged)
 
     future_data <- m750_lagged %>%
-        filter(is.na(value))
+        dplyr::filter(is.na(value))
 
     # * Recursive Modeling ----
-    wflw_fit_lm <- workflow() %>%
-        add_recipe(recipe(value ~ date, train_data)) %>%
-        add_model(linear_reg() %>% set_engine("lm")) %>%
+    wflw_fit_lm <- workflows::workflow() %>%
+        workflows::add_recipe(recipes::recipe(value ~ date, train_data)) %>%
+        workflows::add_model(linear_reg() %>% parsnip::set_engine("lm")) %>%
         fit(train_data)
 
-    wflw_fit_lm_recursive <- workflow() %>%
-        add_recipe(recipe(value ~ ., train_data)) %>%
-        add_model(linear_reg() %>% set_engine("lm")) %>%
+    wflw_fit_lm_recursive <- workflows::workflow() %>%
+        workflows::add_recipe(recipes::recipe(value ~ ., train_data)) %>%
+        workflows::add_model(linear_reg() %>% parsnip::set_engine("lm")) %>%
         fit(train_data) %>%
         recursive(
             transform  = lag_transformer,
@@ -153,7 +151,7 @@ test_that("Chunked Recursive Tests - Uneven ", {
 
     # forecast_tbl %>% plot_modeltime_forecast()
 
-    preds <- forecast_tbl %>% filter(.model_id == 2) %>% pull(.value)
+    preds <- forecast_tbl %>% dplyr::filter(.model_id == 2) %>% dplyr::pull(.value)
     expect_equal(
         length(future_data$value),
         length(preds)
@@ -164,8 +162,8 @@ test_that("Chunked Recursive Tests - Uneven ", {
 
     # * Modeltime Refit ----
 
-    retrain_tbl <- train_data %>% slice(1:200)
-    future_tbl  <- train_data %>% slice(201:224)
+    retrain_tbl <- train_data %>% dplyr::slice_head(n = 200)
+    future_tbl  <- train_data %>% dplyr::slice(201:224)
 
     # wflw_fit_lm_recursive %>% mdl_time_refit(retrain_tbl)
 
@@ -184,7 +182,7 @@ test_that("Chunked Recursive Tests - Uneven ", {
 
     # forecast_refit_tbl %>% plot_modeltime_forecast()
 
-    preds <- forecast_refit_tbl %>% filter(.model_id == 1) %>% pull(.value)
+    preds <- forecast_refit_tbl %>% dplyr::filter(.model_id == 1) %>% dplyr::pull(.value)
     expect_equal(
         length(future_tbl$value),
         length(preds)
@@ -199,40 +197,39 @@ test_that("Chunked Recursive Tests - Uneven ", {
     # recursive 3 - panel / function / parsnip + workflow
 
     # Jumble the data to make sure it forecasts properly
-    m4_monthly_updated <- m4_monthly %>%
-        arrange(desc(id), date) %>%
-        mutate(id = as_factor(as.character(id)))
+    m4_monthly_updated <- timetk::m4_monthly %>%
+        dplyr::arrange(desc(id), date) %>%
+        dplyr::mutate(id = forcats::as_factor(as.character(id)))
 
     m4_extended <- m4_monthly_updated %>%
-        group_by(id) %>%
-        future_frame(
+        dplyr::group_by(id) %>%
+        timetk::future_frame(
             .length_out = FORECAST_HORIZON,
             .bind_data  = TRUE
         ) %>%
-        ungroup()
+        dplyr::ungroup()
 
     # Transformation Function
     lag_transformer_grouped <- function(data){
         data %>%
-            group_by(id) %>%
+            dplyr::group_by(id) %>%
             # Lags
-            tk_augment_lags(value, .lags = c(3,6,9,12)) %>%
-            ungroup()
+            timetk::tk_augment_lags(value, .lags = c(3,6,9,12)) %>%
+            dplyr::ungroup()
     }
 
     m4_lags <- m4_extended %>%
         lag_transformer_grouped()
 
-    train_data <- m4_lags %>%
-        drop_na()
+    train_data <- tidyr::drop_na(m4_lags)
 
     future_data <- m4_lags %>%
-        filter(is.na(value))
+        dplyr::filter(is.na(value))
 
     # * Recursive Modeling ----
 
     model_fit_lm_recursive <- linear_reg() %>%
-        set_engine("lm") %>%
+        parsnip::set_engine("lm") %>%
         fit(value ~ ., data = train_data) %>%
         recursive(
             id         = "id",
@@ -241,9 +238,9 @@ test_that("Chunked Recursive Tests - Uneven ", {
             chunk_size = 3
         )
 
-    wflw_fit_lm_recursive <- workflow() %>%
-        add_recipe(recipe(value ~ ., train_data)) %>%
-        add_model(linear_reg() %>% set_engine("lm")) %>%
+    wflw_fit_lm_recursive <- workflows::workflow() %>%
+        workflows::add_recipe(recipes::recipe(value ~ ., train_data)) %>%
+        workflows::add_model(linear_reg() %>% parsnip::set_engine("lm")) %>%
         fit(train_data) %>%
         recursive(
             id         = "id",
@@ -264,13 +261,13 @@ test_that("Chunked Recursive Tests - Uneven ", {
     ) %>%
         modeltime_forecast(
             new_data    = future_data,
-            actual_data = m4_monthly,
+            actual_data = timetk::m4_monthly,
             keep_data   = TRUE
         )
 
     # forecast_tbl %>% group_by(id) %>% plot_modeltime_forecast()
-    preds_1 <- forecast_tbl %>% filter(.model_id == 1) %>% pull(.value)
-    preds_2 <- forecast_tbl %>% filter(.model_id == 2) %>% pull(.value)
+    preds_1 <- forecast_tbl %>% dplyr::filter(.model_id == 1) %>% dplyr::pull(.value)
+    preds_2 <- forecast_tbl %>% dplyr::filter(.model_id == 2) %>% dplyr::pull(.value)
     expect_equal(
         length(future_data$value),
         length(preds_1),
@@ -314,8 +311,8 @@ test_that("Chunked Recursive Tests - Uneven ", {
 
     # forecast_refit_tbl %>% group_by(id) %>% plot_modeltime_forecast()
 
-    preds_1 <- forecast_refit_tbl %>% filter(.model_id == 1) %>% pull(.value)
-    preds_2 <- forecast_refit_tbl %>% filter(.model_id == 2) %>% pull(.value)
+    preds_1 <- forecast_refit_tbl %>% dplyr::filter(.model_id == 1) %>% dplyr::pull(.value)
+    preds_2 <- forecast_refit_tbl %>% dplyr::filter(.model_id == 2) %>% dplyr::pull(.value)
 
     expect_equal(
         length(future_tbl$value),
@@ -346,26 +343,25 @@ test_that("Chunked Recursive Tests - Single ", {
     # recursive 1 - single / recipe / parsnip ----
 
     # Lag Recipe
-    recipe_lag <- recipe(value ~ date, m750_extended) %>%
+    recipe_lag <- recipes::recipe(value ~ date, m750_extended) %>%
         step_lag(value, lag = c(3,6,9,12))
 
     # Data Transformation
     m750_lagged <- recipe_lag %>% prep() %>% juice()
 
-    train_data <- m750_lagged %>%
-        drop_na()
+    train_data <- tidyr::drop_na(m750_lagged)
 
     future_data <- m750_lagged %>%
-        filter(is.na(value))
+        dplyr::filter(is.na(value))
 
 
     # * Recursive Modeling ----
     model_fit_lm <- linear_reg() %>%
-        set_engine("lm") %>%
+        parsnip::set_engine("lm") %>%
         fit(value ~ date, data = train_data)
 
     model_fit_lm_recursive <- linear_reg() %>%
-        set_engine("lm") %>%
+        parsnip::set_engine("lm") %>%
         fit(value ~ ., data = train_data) %>%
         recursive(
             transform  = recipe_lag,
@@ -386,7 +382,7 @@ test_that("Chunked Recursive Tests - Single ", {
             keep_data   = TRUE
         )
 
-    preds <- forecast_tbl %>% filter(.model_id == 2) %>% pull(.value)
+    preds <- forecast_tbl %>% dplyr::filter(.model_id == 2) %>% dplyr::pull(.value)
     expect_equal(
         length(future_data$value),
         length(preds)
@@ -413,7 +409,7 @@ test_that("Chunked Recursive Tests - Single ", {
             actual_data = retrain_tbl
         )
 
-    preds <- forecast_refit_tbl %>% filter(.model_id == 1) %>% pull(.value)
+    preds <- forecast_refit_tbl %>% dplyr::filter(.model_id == 1) %>% dplyr::pull(.value)
     expect_equal(
         length(future_tbl$value),
         length(preds)
@@ -439,23 +435,22 @@ test_that("Chunked Recursive Tests - Single ", {
     # Data Preparation
     m750_lagged <- m750_extended %>%
         lag_transformer() %>%
-        select(-id)
+        dplyr::select(-id)
 
-    train_data <- m750_lagged %>%
-        drop_na()
+    train_data <- tidyr::drop_na(m750_lagged)
 
     future_data <- m750_lagged %>%
-        filter(is.na(value))
+        dplyr::filter(is.na(value))
 
     # * Recursive Modeling ----
-    wflw_fit_lm <- workflow() %>%
-        add_recipe(recipe(value ~ date, train_data)) %>%
-        add_model(linear_reg() %>% set_engine("lm")) %>%
+    wflw_fit_lm <- workflows::workflow() %>%
+        workflows::add_recipe(recipes::recipe(value ~ date, train_data)) %>%
+        workflows::add_model(linear_reg() %>% parsnip::set_engine("lm")) %>%
         fit(train_data)
 
-    wflw_fit_lm_recursive <- workflow() %>%
-        add_recipe(recipe(value ~ ., train_data)) %>%
-        add_model(linear_reg() %>% set_engine("lm")) %>%
+    wflw_fit_lm_recursive <- workflows::workflow() %>%
+        workflows::add_recipe(recipes::recipe(value ~ ., train_data)) %>%
+        workflows::add_model(linear_reg() %>% parsnip::set_engine("lm")) %>%
         fit(train_data) %>%
         recursive(
             transform  = lag_transformer,
@@ -478,7 +473,7 @@ test_that("Chunked Recursive Tests - Single ", {
 
     # forecast_tbl %>% plot_modeltime_forecast()
 
-    preds <- forecast_tbl %>% filter(.model_id == 2) %>% pull(.value)
+    preds <- forecast_tbl %>% dplyr::filter(.model_id == 2) %>% dplyr::pull(.value)
     expect_equal(
         length(future_data$value),
         length(preds)
@@ -509,7 +504,7 @@ test_that("Chunked Recursive Tests - Single ", {
 
     # forecast_refit_tbl %>% plot_modeltime_forecast()
 
-    preds <- forecast_refit_tbl %>% filter(.model_id == 1) %>% pull(.value)
+    preds <- forecast_refit_tbl %>% dplyr::filter(.model_id == 1) %>% dplyr::pull(.value)
     expect_equal(
         length(future_tbl$value),
         length(preds)
@@ -524,40 +519,39 @@ test_that("Chunked Recursive Tests - Single ", {
     # recursive 3 - panel / function / parsnip + workflow
 
     # Jumble the data to make sure it forecasts properly
-    m4_monthly_updated <- m4_monthly %>%
-        arrange(desc(id), date) %>%
-        mutate(id = as_factor(as.character(id)))
+    m4_monthly_updated <- timetk::m4_monthly %>%
+        dplyr::arrange(desc(id), date) %>%
+        dplyr::mutate(id = forcats::as_factor(as.character(id)))
 
     m4_extended <- m4_monthly_updated %>%
-        group_by(id) %>%
-        future_frame(
+        dplyr::group_by(id) %>%
+        timetk::future_frame(
             .length_out = FORECAST_HORIZON,
             .bind_data  = TRUE
         ) %>%
-        ungroup()
+        dplyr::ungroup()
 
     # Transformation Function
     lag_transformer_grouped <- function(data){
         data %>%
-            group_by(id) %>%
+            dplyr::group_by(id) %>%
             # Lags
-            tk_augment_lags(value, .lags = c(3,6,9,12)) %>%
-            ungroup()
+            timetk::tk_augment_lags(value, .lags = c(3,6,9,12)) %>%
+            dplyr::ungroup()
     }
 
     m4_lags <- m4_extended %>%
         lag_transformer_grouped()
 
-    train_data <- m4_lags %>%
-        drop_na()
+    train_data <- tidyr::drop_na(m4_lags)
 
     future_data <- m4_lags %>%
-        filter(is.na(value))
+        dplyr::filter(is.na(value))
 
     # * Recursive Modeling ----
 
     model_fit_lm_recursive <- linear_reg() %>%
-        set_engine("lm") %>%
+        parsnip::set_engine("lm") %>%
         fit(value ~ ., data = train_data) %>%
         recursive(
             id         = "id",
@@ -566,9 +560,9 @@ test_that("Chunked Recursive Tests - Single ", {
             chunk_size = 3
         )
 
-    wflw_fit_lm_recursive <- workflow() %>%
-        add_recipe(recipe(value ~ ., train_data)) %>%
-        add_model(linear_reg() %>% set_engine("lm")) %>%
+    wflw_fit_lm_recursive <- workflows::workflow() %>%
+        workflows::add_recipe(recipes::recipe(value ~ ., train_data)) %>%
+        workflows::add_model(linear_reg() %>% parsnip::set_engine("lm")) %>%
         fit(train_data) %>%
         recursive(
             id         = "id",
@@ -589,13 +583,13 @@ test_that("Chunked Recursive Tests - Single ", {
     ) %>%
         modeltime_forecast(
             new_data    = future_data,
-            actual_data = m4_monthly,
+            actual_data = timetk::m4_monthly,
             keep_data   = TRUE
         )
 
     # forecast_tbl %>% group_by(id) %>% plot_modeltime_forecast()
-    preds_1 <- forecast_tbl %>% filter(.model_id == 1) %>% pull(.value)
-    preds_2 <- forecast_tbl %>% filter(.model_id == 2) %>% pull(.value)
+    preds_1 <- forecast_tbl %>% dplyr::filter(.model_id == 1) %>% dplyr::pull(.value)
+    preds_2 <- forecast_tbl %>% dplyr::filter(.model_id == 2) %>% dplyr::pull(.value)
     expect_equal(
         length(future_data$value),
         length(preds_1),
@@ -639,8 +633,8 @@ test_that("Chunked Recursive Tests - Single ", {
 
     # forecast_refit_tbl %>% group_by(id) %>% plot_modeltime_forecast()
 
-    preds_1 <- forecast_refit_tbl %>% filter(.model_id == 1) %>% pull(.value)
-    preds_2 <- forecast_refit_tbl %>% filter(.model_id == 2) %>% pull(.value)
+    preds_1 <- forecast_refit_tbl %>% dplyr::filter(.model_id == 1) %>% dplyr::pull(.value)
+    preds_2 <- forecast_refit_tbl %>% dplyr::filter(.model_id == 2) %>% dplyr::pull(.value)
 
     expect_equal(
         length(future_tbl$value),
